@@ -79,18 +79,22 @@ class MIDITime(object):
             days_since_epoch = self.mymidi.days_since_epoch(week_start_date)
 
         '''
-        year_start = datetime(int(year), 1, 1).date()
+        year_start = datetime.datetime(int(year), 1, 1).date()
         year_start_day = year_start.weekday()
-        week_start_date = year_start + timedelta(weeks=1 * (int(week_num) - 1))
+        week_start_date = year_start + datetime.timedelta(weeks=1 * (int(week_num) - 1))
         week_start_day = week_start_date.weekday()
         if desired_day_num and week_start_day < desired_day_num:
-            return week_start_date + timedelta(days=(desired_day_num - week_start_day))
+            return week_start_date + datetime.timedelta(days=(desired_day_num - week_start_day))
         return week_start_date
 
-    def get_data_range(self, data_list, attribute_name):
+    def get_data_range(self, data_list, attribute_name, ignore_nulls=True):
         data_list = list(data_list)  # If the data is still a CSV object, once you loop through it you'll get rewind issues. So coercing to list.
-        minimum = min([float(d[attribute_name]) for d in data_list])
-        maximum = max([float(d[attribute_name]) for d in data_list])
+        if ignore_nulls:
+            minimum = min([float(d[attribute_name]) for d in data_list if d[attribute_name]])
+            maximum = max([float(d[attribute_name]) for d in data_list if d[attribute_name]])
+        else:
+            minimum = min([float(d[attribute_name]) for d in data_list])
+            maximum = max([float(d[attribute_name]) for d in data_list])
         return [minimum, maximum]
 
     def scale_to_note_classic(self, scale_pct, mode):  # Only works in multi-octave mode if in C Major (i.e. all the notes are used. Should not be used in other keys, unless octave range is 1.)
@@ -220,14 +224,19 @@ class MIDITime(object):
             # Tracks are numbered from zero. Times are measured in beats.
             track = i
             time = 0
-            channel = 0
 
             # Add track name and tempo.
             self.MIDIFile.addTrackName(track, time, "Track 1")
             self.MIDIFile.addTempo(track, time, self.tempo)
 
             for n in note_list:
-                self.add_note(track, channel, n)
+                if len(n) == 2:
+                    note = n[0]
+                    channel = n[1]
+                else:
+                    note = n
+                    channel = 0
+                self.add_note(track, channel, note)
 
         # And write it to disk.
         binfile = open(self.outfile, 'wb')
